@@ -21,3 +21,6 @@ knockout.mapping_2.4.1.js
 
 # interfaces/Glitter/templates/static/javascripts/moment-2.26.0.min.js
 moment_2.26.0.js
+
+# interfaces/Glitter/templates/static/javascripts/jquery.hotkeys.min.js
+jquery.hotkeys.js
