@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2024 by The SABnzbd-Team (sabnzbd.org)
+# Copyright 2007-2025 by The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -31,6 +31,7 @@ ANFO = namedtuple("ANFO", "article_sum cache_size cache_limit")
 # Or, when extra ".1", ".2" etc. are added for identically named jobs
 DEF_FOLDER_MAX = 256 - 10
 DEF_FILE_MAX = 255 - 10  # max filename length on modern filesystems, minus some room for extra chars later on
+DEX_FILE_EXTENSION_MAX = 20
 
 GIGI = float(2**30)
 MEBI = float(2**20)
@@ -49,7 +50,7 @@ RENAMES_FILE = "__renames__"
 ATTRIB_FILE = "SABnzbd_attrib"
 REPAIR_REQUEST = "repair-all.sab"
 
-SABCTOOLS_VERSION_REQUIRED = "8.2.0"
+SABCTOOLS_VERSION_REQUIRED = "8.2.5"
 
 DB_HISTORY_VERSION = 1
 DB_HISTORY_NAME = "history%s.db" % DB_HISTORY_VERSION
@@ -74,8 +75,9 @@ DEF_LOG_ERRFILE = "sabnzbd.error.log"
 DEF_LOG_CHERRY = "cherrypy.log"
 DEF_ARTICLE_CACHE_DEFAULT = "500M"
 DEF_ARTICLE_CACHE_MAX = "1G"
-DEF_TIMEOUT = 60
-DEF_TEST_TIMEOUT = 5
+DEF_NETWORKING_TIMEOUT = 60
+DEF_NETWORKING_TEST_TIMEOUT = 5
+DEF_NETWORKING_SHORT_TIMEOUT = 3
 DEF_SCANRATE = 5
 DEF_HTTPS_CERT_FILE = "server.cert"
 DEF_HTTPS_KEY_FILE = "server.key"
@@ -100,6 +102,7 @@ SOFT_QUEUE_LIMIT = 0.5
 # Percentage of cache to use before adding file to assembler
 ASSEMBLER_WRITE_THRESHOLD = 5
 NNTP_BUFFER_SIZE = int(800 * KIBI)
+NTTP_MAX_BUFFER_SIZE = int(10 * MEBI)
 
 REPAIR_PRIORITY = 3
 FORCE_PRIORITY = 2
