@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2008-2024 by The SABnzbd-Team (sabnzbd.org)
+# Copyright 2008-2025 by The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -39,13 +39,22 @@ from typing import Union, List, Tuple, Any, Dict, Optional, BinaryIO
 try:
     import win32api
     import win32file
+    import win32con
 except ImportError:
     pass
 
 import sabnzbd
 from sabnzbd.decorators import synchronized, cache_maintainer
-from sabnzbd.constants import FUTURE_Q_FOLDER, JOB_ADMIN, GIGI, DEF_FILE_MAX, IGNORED_FILES_AND_FOLDERS, DEF_LOG_FILE
-from sabnzbd.encoding import correct_unknown_encoding, utob, ubtou
+from sabnzbd.constants import (
+    FUTURE_Q_FOLDER,
+    JOB_ADMIN,
+    GIGI,
+    DEF_FILE_MAX,
+    IGNORED_FILES_AND_FOLDERS,
+    DEF_LOG_FILE,
+    DEX_FILE_EXTENSION_MAX,
+)
+from sabnzbd.encoding import correct_unknown_encoding, utob, limit_encoded_length
 from sabnzbd.utils import rarfile
 
 
@@ -193,69 +202,47 @@ def has_win_device(filename: str) -> bool:
 
 
 CH_ILLEGAL = "\0/"
-CH_LEGAL = "_+"
 CH_ILLEGAL_WIN = '\\/<>?*|":'
-CH_LEGAL_WIN = "++{}!@#'-"
 for i in range(1, 32):
     CH_ILLEGAL_WIN += chr(i)
-    CH_LEGAL_WIN += "_"
 
 
-def sanitize_filename(name: str) -> str:
+def sanitize_filename(filename: str) -> str:
     """Return filename with illegal chars converted to legal ones
     and with the par2 extension always in lowercase
     """
-    if not name:
-        return name
+    if not filename:
+        return filename
 
     illegal = CH_ILLEGAL
-    legal = CH_LEGAL
-
-    if sabnzbd.WIN32 or sabnzbd.cfg.sanitize_safe():
+    if sabnzbd.WINDOWS or sabnzbd.cfg.sanitize_safe():
         # Remove all bad Windows chars too
         illegal += CH_ILLEGAL_WIN
-        legal += CH_LEGAL_WIN
 
-    if ":" in name and sabnzbd.MACOS:
+    if sabnzbd.MACOS:
         # Compensate for the foolish way par2 on macOS handles a colon character
-        name = name[name.rfind(":") + 1 :]
+        illegal += ":"
 
-    lst = []
-    for ch in name.strip():
-        if ch in illegal:
-            ch = legal[illegal.find(ch)]
-        lst.append(ch)
-    name = "".join(lst)
+    # Replace all illegal characters by an underscore
+    filename = filename.strip().translate(str.maketrans(illegal, "_" * len(illegal)))
 
-    if sabnzbd.WIN32 or sabnzbd.cfg.sanitize_safe():
-        name = replace_win_devices(name)
+    if sabnzbd.WINDOWS or sabnzbd.cfg.sanitize_safe():
+        filename = replace_win_devices(filename)
 
-    if not name:
-        name = "unknown"
+    if not filename:
+        filename = "unknown"
 
     # now split name into name, ext
-    name, ext = os.path.splitext(name)
+    basename, ext = os.path.splitext(filename)
 
-    # If filename is too long (more than DEF_FILE_MAX bytes), brute-force truncate it,
-    # preserving the extension (max ext length 20)
+    # If filename is too long (more than DEF_FILE_MAX bytes), brute-force truncate it, preserving the extension
     # Note: some filesystem can handle up to 255 UTF chars (which is more than 255 bytes) in the filename,
     # but we stay on the safe side: max DEF_FILE_MAX bytes
     try:
-        if len(utob(name)) + len(utob(ext)) > DEF_FILE_MAX:
-            logging.debug("Filename %s is too long, so truncating", name + ext)
-            # Too long filenames are often caused by incorrect non-ascii chars,
-            # so brute-force remove those non-ascii chars
-            name = ubtou(name.encode("ascii", "ignore"))
-            # Now it's plain ASCII, so no need for len(str.encode()) anymore; plain len() is enough
-            if len(name) + len(ext) > DEF_FILE_MAX:
-                # still too long, limit the extension
-                maxextlength = 20  # max length of an extension
-                if len(ext) > maxextlength:
-                    # allow first <maxextlength> chars, including the starting dot
-                    ext = ext[:maxextlength]
-                if len(name) + len(ext) > DEF_FILE_MAX:
-                    # Still too long, limit the basename
-                    name = name[: DEF_FILE_MAX - len(ext)]
+        if len(utob(filename)) > DEF_FILE_MAX:
+            logging.debug("Filename %s is too long, so truncating", filename + ext)
+            ext = limit_encoded_length(ext, DEX_FILE_EXTENSION_MAX)
+            basename = limit_encoded_length(basename, DEF_FILE_MAX - len(ext))
     except UnicodeError:
         # Just in case of strange encoding problems, like #2714
         pass
@@ -263,57 +250,50 @@ def sanitize_filename(name: str) -> str:
     lowext = ext.lower()
     if lowext == ".par2" and lowext != ext:
         ext = lowext
-    return name + ext
+    return basename + ext
 
 
-def sanitize_foldername(name: str) -> str:
+def sanitize_foldername(foldername: str) -> str:
     """Return foldername with dodgy chars converted to safe ones
     Remove any leading and trailing dot and space characters
     """
-    if not name:
-        return name
+    if not foldername:
+        return foldername
 
     illegal = CH_ILLEGAL + ':"'
-    legal = CH_LEGAL + "-'"
 
-    if sabnzbd.WIN32 or sabnzbd.cfg.sanitize_safe():
+    if sabnzbd.WINDOWS or sabnzbd.cfg.sanitize_safe():
         # Remove all bad Windows chars too
         illegal += CH_ILLEGAL_WIN
-        legal += CH_LEGAL_WIN
 
-    lst = []
-    for ch in name.strip():
-        if ch in illegal:
-            ch = legal[illegal.find(ch)]
-            lst.append(ch)
-        else:
-            lst.append(ch)
-    name = "".join(lst)
+    # Replace all illegal characters by an underscore
+    foldername = foldername.strip().translate(str.maketrans(illegal, "_" * len(illegal)))
 
-    if sabnzbd.WIN32 or sabnzbd.cfg.sanitize_safe():
-        name = replace_win_devices(name)
+    if sabnzbd.WINDOWS or sabnzbd.cfg.sanitize_safe():
+        foldername = replace_win_devices(foldername)
 
-    if len(name) >= sabnzbd.cfg.max_foldername_length():
-        name = name[: sabnzbd.cfg.max_foldername_length()]
+    # Make sure we check the underlying unicode length!
+    if len(utob(foldername)) >= sabnzbd.cfg.max_foldername_length():
+        foldername = limit_encoded_length(foldername, sabnzbd.cfg.max_foldername_length())
 
     # And finally, make sure it doesn't end in a dot or a space
     # This is invalid on Windows and can cause trouble for some other tools
-    if name != "." and name != "..":
-        while len(name) > len(name := name.strip().rstrip(".")):
+    if foldername != "." and foldername != "..":
+        while len(foldername) > len(foldername := foldername.strip().rstrip(".")):
             continue
 
     # Just to be sure we don't return nothing
-    if not name:
-        name = "unknown"
+    if not foldername:
+        foldername = "unknown"
 
-    return name
+    return foldername
 
 
 def sanitize_and_trim_path(path: str) -> str:
     """Remove illegal characters and trim element size"""
     path = path.strip()
     new_path = ""
-    if sabnzbd.WIN32:
+    if sabnzbd.WINDOWS:
         if path.startswith("\\\\?\\UNC\\"):
             new_path = "\\\\?\\UNC\\"
             path = path[8:]
@@ -323,7 +303,7 @@ def sanitize_and_trim_path(path: str) -> str:
 
     path = path.replace("\\", "/")
     parts = path.split("/")
-    if sabnzbd.WIN32 and len(parts[0]) == 2 and ":" in parts[0]:
+    if sabnzbd.WINDOWS and len(parts[0]) == 2 and ":" in parts[0]:
         new_path += parts[0] + "/"
         parts.pop(0)
     elif path.startswith("//"):
@@ -372,9 +352,9 @@ def real_path(loc: str, path: str) -> str:
     else:
         path = ""
     if path:
-        if not sabnzbd.WIN32 and path.startswith("~/"):
+        if not sabnzbd.WINDOWS and path.startswith("~/"):
             path = path.replace("~", os.environ.get("HOME", sabnzbd.DIR_HOME), 1)
-        if sabnzbd.WIN32:
+        if sabnzbd.WINDOWS:
             # The Windows-functions work differently on long-path
             # So we bring it back to normal and make it long-path at the end
             loc = clip_path(loc)
@@ -431,14 +411,14 @@ def same_directory(a: str, b: str) -> int:
     return 1 if A and B are actually the same path
     return 2 if B is a sub-folder of A
     """
-    if sabnzbd.WIN32 or sabnzbd.MACOS:
+    if sabnzbd.WINDOWS or sabnzbd.MACOS:
         a = clip_path(a.lower())
         b = clip_path(b.lower())
 
     a = os.path.normpath(os.path.abspath(a))
     b = os.path.normpath(os.path.abspath(b))
 
-    # Need to add seperator so /mnt/sabnzbd and /mnt/sabnzbd-data are not detected as equal
+    # Need to add separator so /mnt/sabnzbd and /mnt/sabnzbd-data are not detected as equal
     # But only if it doesn't already end in a slash, for example C:\
     if not a.endswith(os.sep):
         a = a + os.sep
@@ -469,7 +449,7 @@ def is_network_path(path: str) -> bool:
     path = clip_path(path)
     if path.startswith(r"\\"):
         return True
-    if sabnzbd.WIN32:
+    if sabnzbd.WINDOWS:
         drive_letter, _ = os.path.splitdrive(path)
         return win32file.GetDriveType(drive_letter) == win32file.DRIVE_REMOTE
     return False
@@ -482,7 +462,7 @@ def mount_is_available(path: str) -> bool:
     """
     if sabnzbd.MACOS:
         m = re.search(r"^(/Volumes/[^/]+)", path, re.I)
-    elif sabnzbd.WIN32:
+    elif sabnzbd.WINDOWS:
         m = re.search(r"^([a-z]:\\)", path, re.I)
     else:
         m = re.search(r"^(/(?:mnt|media)/[^/]+)", path)
@@ -577,7 +557,7 @@ def fix_unix_encoding(folder: str):
     This happens for example when files are created
     on Windows but unpacked/repaired on linux
     """
-    if not sabnzbd.WIN32 and not sabnzbd.MACOS:
+    if not sabnzbd.WINDOWS and not sabnzbd.MACOS:
         for root, dirs, files in os.walk(folder):
             for name in files:
                 new_name = correct_unknown_encoding(name)
@@ -602,12 +582,12 @@ def list_scripts(default: bool = False, none: bool = True) -> List[str]:
             if os.path.isfile(script):
                 if (
                     (
-                        sabnzbd.WIN32
+                        sabnzbd.WINDOWS
                         and get_ext(script) in PATHEXT
                         and not win32api.GetFileAttributes(script) & win32file.FILE_ATTRIBUTE_HIDDEN
                     )
                     or script.endswith(".py")
-                    or (not sabnzbd.WIN32 and userxbit(script) and not os.path.basename(script).startswith("."))
+                    or (not sabnzbd.WINDOWS and userxbit(script) and not os.path.basename(script).startswith("."))
                 ):
                     lst.append(os.path.basename(script))
             # Make sure capitalization is ignored to avoid strange results
@@ -659,7 +639,7 @@ def set_chmod(path: str, permissions: int, allow_failures: bool = False):
 
 def set_permissions(path: str, recursive: bool = True):
     """Give folder tree and its files their proper permissions"""
-    if not sabnzbd.WIN32:
+    if not sabnzbd.WINDOWS:
         if custom_permissions := sabnzbd.cfg.permissions():
             # If user set permissions, parse them
             custom_permissions = int(custom_permissions, 8)
@@ -713,14 +693,14 @@ def userxbit(path: str) -> bool:
 
 def clip_path(path: str) -> str:
     r"""Remove \\?\ or \\?\UNC\ prefix from Windows path"""
-    if sabnzbd.WIN32 and path and "?" in path:
+    if sabnzbd.WINDOWS and path and "?" in path:
         path = path.replace("\\\\?\\UNC\\", "\\\\", 1).replace("\\\\?\\", "", 1)
     return path
 
 
 def long_path(path: str) -> str:
     """For Windows, convert to long style path; others, return same path"""
-    if sabnzbd.WIN32 and path and not path.startswith("\\\\?\\"):
+    if sabnzbd.WINDOWS and path and not path.startswith("\\\\?\\"):
         if path.startswith("\\\\"):
             # Special form for UNC paths
             path = path.replace("\\\\", "\\\\?\\UNC\\", 1)
@@ -744,7 +724,7 @@ def create_all_dirs(path: str, apply_permissions: bool = False) -> Union[str, bo
     """
     try:
         logging.info("Creating directories: %s", path)
-        if sabnzbd.WIN32:
+        if sabnzbd.WINDOWS:
             # On Windows it can fail on UNC-paths in long-path notation
             # https://bugs.python.org/issue41705
             if not os.path.exists(path):
@@ -914,7 +894,7 @@ def renamer(old: str, new: str, create_local_directories: bool = False) -> str:
             create_all_dirs(path)
 
     logging.debug('Renaming "%s" to "%s"', old, new)
-    if sabnzbd.WIN32:
+    if sabnzbd.WINDOWS:
         retries = 10
         while retries > 0:
             try:
@@ -957,7 +937,7 @@ def remove_file(path: str):
 def remove_dir(path: str):
     """Remove directory with retries for Win32"""
     logging.debug("[%s] Removing dir %s", sabnzbd.misc.caller_name(), path)
-    if sabnzbd.WIN32:
+    if sabnzbd.WINDOWS:
         retries = 15
         while retries > 0:
             try:
@@ -990,7 +970,7 @@ def remove_all(path: str, pattern: str = "*", keep_folder: bool = False, recursi
         else:
             # Get files based on pattern
             files = globber_full(path, pattern)
-            if pattern == "*" and not sabnzbd.WIN32:
+            if pattern == "*" and not sabnzbd.WINDOWS:
                 files.extend(globber_full(path, ".*"))
 
             for f in files:
@@ -1062,7 +1042,7 @@ def diskspace_base(dir_to_check: str) -> Tuple[float, float]:
     while x and not os.path.exists(dir_to_check):
         dir_to_check, x = os.path.split(dir_to_check)
 
-    if sabnzbd.WIN32:
+    if sabnzbd.WINDOWS:
         # windows diskfree
         try:
             available, disk_size, total_free = win32api.GetDiskFreeSpaceEx(dir_to_check)
@@ -1310,10 +1290,126 @@ def check_filesystem_capabilities(test_dir: str) -> bool:
         allgood = False
 
     # if not on Windows, check special chars like \ and :
-    if not sabnzbd.WIN32 and not directory_is_writable_with_file(test_dir, "sab_test \\ bla :: , bla.txt"):
+    if not sabnzbd.WINDOWS and not directory_is_writable_with_file(test_dir, "sab_test \\ bla :: , bla.txt"):
         sabnzbd.misc.helpful_warning(
             T("%s is not writable with special character filenames. This can cause problems."), test_dir
         )
         allgood = False
 
     return allgood
+
+
+def get_win_drives() -> List[str]:
+    """Return list of detected drives, adapted from:
+    http://stackoverflow.com/questions/827371/is-there-a-way-to-list-all-the-available-drive-letters-in-python/827490
+    """
+    return filter(len, win32api.GetLogicalDriveStrings().split("\000"))
+
+
+PATHBROWSER_JUNKFOLDERS = (
+    "boot",
+    "bootmgr",
+    "cache",
+    "msocache",
+    "recovery",
+    "$recycle.bin",
+    "recycler",
+    "system volume information",
+    "temporary internet files",
+    "perflogs",  # windows specific
+    ".fseventd",
+    ".spotlight",
+    ".trashes",
+    ".vol",
+    "cachedmessages",
+    "caches",
+    "trash",  # osx specific
+)
+
+
+def pathbrowser(path: str, show_hidden: bool = False, show_files: bool = False) -> List[Dict[str, str]]:
+    """Returns a list of dictionaries with the folders and folders contained at the given path
+    Give the empty string as the path to list the contents of the root path
+    under Unix this means "/", on Windows this will be a list of drive letters
+    """
+    if path == "":
+        if sabnzbd.WINDOWS:
+            entries = [{"current_path": "Root"}]
+            for letter in get_win_drives():
+                entries.append(
+                    {
+                        "name": letter,
+                        "path": letter,
+                        "dir": True,
+                    }
+                )
+            return entries
+        else:
+            path = "/"
+
+    # Walk up the tree until we find a valid path
+    path = real_path(sabnzbd.DIR_HOME, path)
+    while path and not os.path.isdir(path):
+        if path == os.path.dirname(path):
+            return pathbrowser(path="")
+        else:
+            path = os.path.dirname(path)
+
+    # Fix up the path and find the parent
+    path = os.path.abspath(os.path.normpath(path))
+    parent_path = os.path.dirname(path)
+
+    # If we're at the root then the next step is the meta-node showing our drive letters
+    if path == parent_path and sabnzbd.WINDOWS:
+        parent_path = ""
+
+    # List all files and folders
+    file_list = []
+    for filename in os.listdir(path):
+        fpath = os.path.join(path, filename)
+        isdir = os.path.isdir(fpath)
+
+        # Skip unwanted folders
+        if isdir and filename.lower() in PATHBROWSER_JUNKFOLDERS:
+            continue
+
+        # Skip files
+        if not isdir and not show_files:
+            continue
+
+        # Skip hidden files
+        if not show_hidden:
+            if sabnzbd.WINDOWS:
+                try:
+                    if win32api.GetFileAttributes(fpath) & win32con.FILE_ATTRIBUTE_HIDDEN:
+                        continue
+                except win32api.error:
+                    # Can be thrown if file is in use
+                    continue
+            elif filename.startswith("."):
+                continue
+
+        file_list.append(
+            {
+                "name": clip_path(filename),
+                "path": clip_path(fpath),
+                "dir": isdir,
+            }
+        )
+
+    # Sort results, folders first (using string value of the bool)
+    file_list = sorted(file_list, key=lambda x: str(not x["dir"]) + os.path.basename(x["name"]).lower())
+
+    # Add current path
+    file_list.insert(0, {"current_path": clip_path(path)})
+    if parent_path != path:
+        file_list.insert(
+            1,
+            {
+                "name": "..",
+                "path": clip_path(parent_path),
+                "dir": True,
+            },
+        )
+
+    return file_list
