@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2024 by The SABnzbd-Team (sabnzbd.org)
+# Copyright 2007-2025 by The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -34,7 +34,7 @@ import copy
 from random import randint
 from xml.sax.saxutils import escape
 from Cheetah.Template import Template
-from typing import Optional, Callable, Union, Any, Dict
+from typing import Optional, Callable, Union, Any, Dict, List
 from guessit.api import properties as guessit_properties
 
 import sabnzbd
@@ -80,7 +80,7 @@ from sabnzbd.constants import (
     GUESSIT_SORT_TYPES,
     VALID_NZB_FILES,
     VALID_ARCHIVES,
-    DEF_TEST_TIMEOUT,
+    DEF_NETWORKING_TEST_TIMEOUT,
 )
 from sabnzbd.lang import list_languages
 from sabnzbd.api import (
@@ -264,6 +264,19 @@ def check_hostname():
 COOKIE_SECRET = str(randint(1000, 100000) * os.getpid())
 
 
+def remote_ip_from_xff(xff_ips: List[str]) -> str:
+    # Per MDN docs, the first non-local/non-trusted IP (rtl) is our "client"
+    # However, it's possible that all IPs are local/trusted, so we may also
+    # return the first ip in the list as it "should" be the client
+    # https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/X-Forwarded-For#selecting_an_ip_address
+    for ip in reversed(xff_ips):
+        if not is_local_addr(ip) and not is_loopback_addr(ip):
+            return ip
+    else:
+        # If no non-local/non-trusted IPs found, return the first IP in the list
+        return xff_ips[0]
+
+
 def set_login_cookie(remove=False, remember_me=False):
     """We try to set a cookie as unique as possible
     to the current user. Based on it's IP and the
@@ -271,7 +284,16 @@ def set_login_cookie(remove=False, remember_me=False):
     number, so cookies cannot be re-used
     """
     salt = randint(1, 1000)
-    cookie_str = utob(str(salt) + cherrypy.request.remote.ip + COOKIE_SECRET)
+
+    # If we are using XFF headers, get remote IP from XFF if possible
+    if cfg.verify_xff_header() and (
+        xff_ips := clean_comma_separated_list(cherrypy.request.headers.get("X-Forwarded-For"))
+    ):
+        remote_ip = remote_ip_from_xff(xff_ips)
+    else:
+        remote_ip = cherrypy.request.remote.ip
+
+    cookie_str = utob(str(salt) + remote_ip + COOKIE_SECRET)
     cherrypy.response.cookie["login_cookie"] = hashlib.sha1(cookie_str).hexdigest()
     cherrypy.response.cookie["login_cookie"]["path"] = "/"
     cherrypy.response.cookie["login_cookie"]["httponly"] = 1
@@ -298,7 +320,15 @@ def check_login_cookie():
     if "login_cookie" not in cherrypy.request.cookie or "login_salt" not in cherrypy.request.cookie:
         return False
 
-    cookie_str = utob(str(cherrypy.request.cookie["login_salt"].value) + cherrypy.request.remote.ip + COOKIE_SECRET)
+    # If we are using XFF headers, get remote IP from XFF if possible
+    if cfg.verify_xff_header() and (
+        xff_ips := clean_comma_separated_list(cherrypy.request.headers.get("X-Forwarded-For"))
+    ):
+        remote_ip = remote_ip_from_xff(xff_ips)
+    else:
+        remote_ip = cherrypy.request.remote.ip
+
+    cookie_str = utob(str(cherrypy.request.cookie["login_salt"].value) + remote_ip + COOKIE_SECRET)
     return cherrypy.request.cookie["login_cookie"].value == hashlib.sha1(cookie_str).hexdigest()
 
 
@@ -395,9 +425,8 @@ def Raiser(root: str = "", **kwargs):
     if kwargs:
         root = "%s?%s" % (root, urllib.parse.urlencode(kwargs))
 
-    # Optionally add the leading /sabnzbd/ (or what the user set)
-    if not root.startswith(cfg.url_base()):
-        root = cherrypy.request.script_name + root
+    # Add the leading /sabnzbd/ (or what the user set)
+    root = cfg.url_base() + root
 
     # Log the redirect
     if cfg.api_logging():
@@ -434,6 +463,7 @@ class MainPage:
 
             info["cpumodel"] = get_cpu_name()
             info["cpusimd"] = sabnzbd.decoder.SABCTOOLS_SIMD
+            info["platform"] = sabnzbd.PLATFORM
 
             # Have logout only with HTML and if inet=5, only when we are external
             info["have_logout"] = (
@@ -502,7 +532,7 @@ class Wizard:
     @secured_expose(check_configlock=True)
     def index(self, **kwargs):
         """Show the language selection page"""
-        if sabnzbd.WIN32:
+        if sabnzbd.WINDOWS:
             from sabnzbd.utils.apireg import get_install_lng
 
             cfg.language.set(get_install_lng())
@@ -577,7 +607,7 @@ class Wizard:
 def get_access_info():
     """Build up a list of url's that sabnzbd can be accessed from"""
     # Access_url is used to provide the user a link to SABnzbd depending on the host
-    cherryhost = cfg.cherryhost()
+    web_host = cfg.web_host()
     host = socket.gethostname().lower()
     logging.info("hostname is", host)
     socks = [host]
@@ -587,7 +617,7 @@ def get_access_info():
     except:
         addresses = []
 
-    if cherryhost == "0.0.0.0":
+    if web_host == "0.0.0.0":
         # Grab a list of all ips for the hostname
         for addr in addresses:
             address = addr[4][0]
@@ -595,7 +625,7 @@ def get_access_info():
             if ":" not in address and address not in socks:
                 socks.append(address)
         socks.insert(0, "localhost")
-    elif cherryhost == "::":
+    elif web_host == "::":
         # Grab a list of all ips for the hostname
         for addr in addresses:
             address = addr[4][0]
@@ -605,8 +635,8 @@ def get_access_info():
                 if address not in socks:
                     socks.append(address)
         socks.insert(0, "localhost")
-    elif cherryhost:
-        socks = [cherryhost]
+    elif web_host:
+        socks = [web_host]
 
     # Add the current requested URL as the base
     access_url = urllib.parse.urljoin(cherrypy.request.base, cfg.url_base())
@@ -617,9 +647,9 @@ def get_access_info():
             if cfg.enable_https() and cfg.https_port():
                 url = "https://%s:%s%s" % (sock, cfg.https_port(), cfg.url_base())
             elif cfg.enable_https():
-                url = "https://%s:%s%s" % (sock, cfg.cherryport(), cfg.url_base())
+                url = "https://%s:%s%s" % (sock, cfg.web_port(), cfg.url_base())
             else:
-                url = "http://%s:%s%s" % (sock, cfg.cherryport(), cfg.url_base())
+                url = "http://%s:%s%s" % (sock, cfg.web_port(), cfg.url_base())
             urls.append(url)
 
     # Return a unique list
@@ -641,7 +671,7 @@ class LoginPage:
 
         # Check if there's even a username/password set
         if check_login():
-            raise Raiser(cherrypy.request.script_name + "/")
+            raise Raiser("/")
 
         # Check login info
         if kwargs.get("username") == cfg.username() and kwargs.get("password") == cfg.password():
@@ -650,7 +680,7 @@ class LoginPage:
             # Log the success
             logging.info("Successful login from %s", cherrypy.request.remote_label)
             # Redirect
-            raise Raiser(cherrypy.request.script_name + "/")
+            raise Raiser("/")
         elif kwargs.get("username") or kwargs.get("password"):
             info["error"] = T("Authentication failed, check username/password.")
             # Warn about the potential security problem
@@ -843,7 +873,6 @@ SPECIAL_BOOL_LIST = (
     "api_warnings",
     "helpful_warnings",
     "ampm",
-    "enable_multipar",
     "enable_unrar",
     "enable_7zip",
     "enable_filejoin",
@@ -882,6 +911,7 @@ SPECIAL_VALUE_LIST = (
     "direct_unpack_threads",
     "selftest_host",
     "ssdp_broadcast_interval",
+    "unrar_parameters",
 )
 SPECIAL_LIST_LIST = (
     "rss_odd_titles",
@@ -1144,7 +1174,9 @@ def handle_server(kwargs, root=None, new_svr=False):
         kwargs["connections"] = "1"
 
     if kwargs.get("enable") == "1":
-        if not happyeyeballs(host, int_conv(port), int_conv(kwargs.get("timeout"), default=DEF_TEST_TIMEOUT)):
+        if not happyeyeballs(
+            host, int_conv(port), int_conv(kwargs.get("timeout"), default=DEF_NETWORKING_TEST_TIMEOUT)
+        ):
             return badParameterResponse(T('Server address "%s:%s" is not valid.') % (host, port), ajax)
 
     # Default server name is just the host name
@@ -2156,8 +2188,10 @@ class ConfigNotify:
 
         for section in NOTIFY_OPTIONS:
             for option in NOTIFY_OPTIONS[section]:
-                # Use get_string to make sure lists are displayed correctly
-                conf[option] = config.get_config(section, option).get_string()
+                conf[option] = config.get_config(section, option)()
+
+        # Use get_string to make sure lists are displayed correctly
+        conf["email_to"] = cfg.email_to.get_string()
 
         return template_filtered_response(
             file=os.path.join(sabnzbd.WEB_DIR_CONFIG, "config_notify.tmpl"),
