@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2024 by The SABnzbd-Team (sabnzbd.org)
+# Copyright 2007-2025 by The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -115,18 +115,9 @@ def find_programs(curdir: str):
         # The 7zip binary is universal2
         sabnzbd.newsunpack.SEVENZIP_COMMAND = check(curdir, "osx/7zip/7zz")
 
-    if sabnzbd.WIN32:
-        if sabnzbd.WIN64:
-            # 64 bit versions
-            sabnzbd.newsunpack.PAR2_COMMAND = check(curdir, "win/par2/x64/par2.exe")
-            sabnzbd.newsunpack.MULTIPAR_COMMAND = check(curdir, "win/multipar/par2j64.exe")
-            sabnzbd.newsunpack.RAR_COMMAND = check(curdir, "win/unrar/x64/UnRAR.exe")
-        else:
-            # 32 bit versions
-            sabnzbd.newsunpack.PAR2_COMMAND = check(curdir, "win/par2/par2.exe")
-            sabnzbd.newsunpack.MULTIPAR_COMMAND = check(curdir, "win/multipar/par2j.exe")
-            sabnzbd.newsunpack.RAR_COMMAND = check(curdir, "win/unrar/UnRAR.exe")
-        # We just use the 32 bit version
+    if sabnzbd.WINDOWS:
+        sabnzbd.newsunpack.PAR2_COMMAND = check(curdir, "win/par2/par2.exe")
+        sabnzbd.newsunpack.RAR_COMMAND = check(curdir, "win/unrar/UnRAR.exe")
         sabnzbd.newsunpack.SEVENZIP_COMMAND = check(curdir, "win/7zip/7za.exe")
     else:
         if not sabnzbd.newsunpack.PAR2_COMMAND:
@@ -163,7 +154,7 @@ def find_programs(curdir: str):
                 )
             )
 
-    if not (sabnzbd.WIN32 or sabnzbd.MACOS):
+    if not (sabnzbd.WINDOWS or sabnzbd.MACOS):
         # Run check on rar version
         version, original = unrar_check(sabnzbd.newsunpack.RAR_COMMAND)
         sabnzbd.newsunpack.RAR_PROBLEM = not original or version < sabnzbd.constants.REC_RAR_VERSION
@@ -344,7 +335,7 @@ def unpacker(
 
     # We can't recursive unpack on long paths on Windows
     # See: https://github.com/sabnzbd/sabnzbd/pull/771
-    if sabnzbd.WIN32 and len(workdir_complete) > 256:
+    if sabnzbd.WINDOWS and len(workdir_complete) > 256:
         rerun = False
 
     # Double-check that we didn't miss any files in workdir
@@ -676,7 +667,7 @@ def rar_extract_core(
         overwrite = "-o-"  # Disable overwrite
         rename = "-or"  # Auto renaming
 
-    if sabnzbd.WIN32:
+    if sabnzbd.WINDOWS:
         # On Windows, UnRar uses a custom argument parser
         # See: https://github.com/sabnzbd/sabnzbd/issues/1043
         # The -scf forces the output to be UTF8
@@ -721,6 +712,9 @@ def rar_extract_core(
 
     if cfg.ignore_unrar_dates():
         command.insert(3, "-tsm-")
+    if not RAR_PROBLEM and (unrar_parameters := cfg.unrar_parameters().strip().split()):
+        for param in unrar_parameters:
+            command.insert(-2, param)
 
     # Get list of all the volumes part of this set
     logging.debug("Analyzing rar file ... %s found", rarfile.is_rarfile(rarfile_path))
@@ -959,7 +953,7 @@ def seven_extract_core(
         method = "e"  # Unpack without folders
     else:
         method = "x"  # Unpack with folders
-    if sabnzbd.WIN32 or sabnzbd.MACOS:
+    if sabnzbd.WINDOWS or sabnzbd.MACOS:
         case = "-ssc-"  # Case insensitive
     else:
         case = "-ssc"  # Case sensitive
@@ -1068,11 +1062,7 @@ def par2_repair(nzo: NzbObject, setname: str) -> Tuple[bool, bool]:
 
             joinables, _, _, _ = build_filelists(nzo.download_path, check_rar=False)
 
-            # Multipar on Windows, par2cmdline on the other platforms
-            if cfg.disable_par2cmdline() and sabnzbd.WIN32:
-                finished, readd, used_joinables, used_for_repair = multipar_verify(parfile, nzo, setname, joinables)
-            else:
-                finished, readd, used_joinables, used_for_repair = par2cmdline_verify(parfile, nzo, setname, joinables)
+            finished, readd, used_joinables, used_for_repair = par2cmdline_verify(parfile, nzo, setname, joinables)
 
             if finished:
                 result = True
@@ -1142,10 +1132,6 @@ def par2cmdline_verify(
     nzo.status = Status.VERIFYING
     start = time.time()
 
-    # Long-path notation isn't supported by par2cmdline
-    if sabnzbd.WIN32:
-        parfile = clip_path(parfile)
-
     # Build command and add extra options
     command = [str(PAR2_COMMAND), "r", parfile]
     if options := cfg.par_option().strip().split():
@@ -1423,342 +1409,6 @@ def par2cmdline_verify(
     return finished, readd, used_joinables, used_for_repair
 
 
-def multipar_verify(
-    parfile: str, nzo: NzbObject, setname: str, joinables: List[str]
-) -> Tuple[bool, bool, List[str], List[str]]:
-    """Run par2 on par-set"""
-    parfolder = os.path.split(parfile)[0]
-    used_joinables = []
-    used_for_repair = []
-
-    # set the current nzo status to "Verifying...". Used in History
-    nzo.status = Status.VERIFYING
-    start = time.time()
-
-    # Caching of verification implemented by adding -vs/-vd
-    # But not really required due to prospective-par2
-    # Force output of utf-8 by adding -uo
-    command = [str(MULTIPAR_COMMAND), "r", "-uo", "-vs2", "-vd%s" % nzo.admin_path, parfile]
-
-    # Only add user-options if supplied
-    options = cfg.par_option().strip().split()
-    if options:
-        for option in options:
-            # We wrongly instructed users to use /x parameter style instead of -x
-            option = option.replace("/", "-", 1)
-            command.insert(2, option)
-
-    # Support bizarre naming conventions by scanning all files
-    if len(nzo.extrapars) == 1 or len(globber(parfolder, setname + "*")) < 2:
-        command.insert(2, "-vl2")
-
-    # Run MultiPar
-    p = build_and_run_command(command)
-    sabnzbd.PostProcessor.external_process = p
-
-    # Set up our variables
-    lines = []
-    renames = {}
-    reconstructed = []
-
-    finished = False
-    readd = False
-
-    verifynum = 0
-    verifytotal = 0
-    verifyextratotal = 0
-
-    in_check = False
-    in_verify = False
-    in_repair = False
-    in_verify_repaired = False
-    misnamed_files = False
-    old_name = None
-
-    # Loop over the output, whee
-    while 1:
-        line = p.stdout.readline()
-        if not line:
-            break
-
-        # Skip empty lines
-        line = line.strip()
-        if not line:
-            continue
-
-        # Save it all
-        lines.append(line)
-
-        # ----------------- Startup
-        if line.startswith("invalid option"):
-            # Option error
-            msg = T("[%s] PAR2 received incorrect options, check your Config->Switches settings") % setname
-            nzo.set_unpack_info("Repair", msg)
-            nzo.status = Status.FAILED
-            logging.error(msg)
-
-        elif line.startswith("valid file is not found"):
-            # Initialparfile probably didn't decode properly, or bad user parameters
-            # We will try to get another par2 file, but 99% of time it's user parameters
-            msg = T("Invalid par2 files or invalid PAR2 parameters, cannot verify or repair")
-            logging.info(msg)
-            logging.info("Extra pars = %s", nzo.extrapars[setname])
-
-            # Look for the smallest par2file
-            block_table = {}
-            for nzf in nzo.extrapars[setname]:
-                if not nzf.completed:
-                    block_table[nzf.blocks] = nzf
-
-            if block_table:
-                nzf = block_table[min(block_table)]
-                logging.info("Found new par2file %s", nzf.filename)
-
-                # Move from extrapar list to files to be downloaded
-                # and remove it from the extrapars list
-                nzo.add_parfile(nzf)
-                readd = True
-            else:
-                nzo.fail_msg = msg
-                nzo.set_unpack_info("Repair", msg, setname)
-                nzo.status = Status.FAILED
-
-        elif line.startswith("There is not enough space on the disk"):
-            msg = T("Repairing failed, %s") % T("Disk full")
-            nzo.fail_msg = msg
-            nzo.set_unpack_info("Repair", msg, setname)
-            nzo.status = Status.FAILED
-
-        # ----------------- Start check/verify stage
-        elif line.startswith("Recovery Set ID"):
-            # Remove files were MultiPar stores verification result when repaired successful
-            recovery_id = line.split()[-1]
-            used_for_repair.append(os.path.join(JOB_ADMIN, "2_%s.bin" % recovery_id))
-            used_for_repair.append(os.path.join(JOB_ADMIN, "2_%s.ini" % recovery_id))
-
-        elif line.startswith("Input File total count"):
-            # How many files will it try to find?
-            verifytotal = int(line.split()[-1])
-
-        # ----------------- Misnamed-detection stage
-        # Misnamed files
-        elif line.startswith("Searching misnamed file"):
-            # We are in the misnamed files block
-            # How many misnamed files will it try to find?
-            verifyextratotal = int(line.split()[-1])
-            verifynum = 0
-            misnamed_files = True
-        elif misnamed_files and "Found" in line:
-            # First it reports the current filename
-            if m := PAR2_FILENAME_RE.search(line):
-                verifynum += 1
-                nzo.set_action_line(T("Checking extra files"), "%02d/%02d" % (verifynum, verifyextratotal))
-                old_name = m.group(1)
-        elif misnamed_files and "Misnamed" in line:
-            # Then it finds the actual
-            m = PAR2_FILENAME_RE.search(line)
-            if m and old_name:
-                new_name = m.group(1)
-                logging.debug('MultiPar will rename "%s" to "%s"', old_name, new_name)
-                renames[new_name] = old_name
-                # New name is also part of data!
-                reconstructed.append(old_name)
-
-        # ----------------- Checking stage
-        # Checking input files
-        elif line.startswith("Complete file count"):
-            in_check = False
-            verifynum = 0
-            old_name = None
-        elif line.startswith("Verifying Input File"):
-            in_check = True
-            nzo.status = Status.VERIFYING
-        elif in_check:
-            if m := PAR2_FILENAME_RE.search(line):
-                # Only increase counter if it was really the detection line
-                if line.startswith("= ") or "%" not in line:
-                    verifynum += 1
-                nzo.set_action_line(T("Checking"), "%02d/%02d" % (verifynum, verifytotal))
-                old_name = m.group(1)
-
-        # ----------------- Verify stage
-        # Which files need extra verification?
-        elif line.startswith("Damaged file count"):
-            verifytotal = int(line.split()[-1])
-
-        elif line.startswith("Missing file count"):
-            verifytotal += int(line.split()[-1])
-
-        # Actual verification
-        elif line.startswith("Input File Slice found"):
-            # End of verification AND end of misnamed file search
-            in_verify = False
-            misnamed_files = False
-            old_name = None
-        elif line.startswith("Finding available slice"):
-            # The actual scanning of the files
-            in_verify = True
-            verifynum = 0
-        elif in_verify:
-            if m := PAR2_FILENAME_RE.search(line):
-                # It prints the filename couple of times, so we save it to check
-                nzo.status = Status.VERIFYING
-                if line.split()[1] in ("Damaged", "Found"):
-                    verifynum += 1
-
-                    # Set old_name in case it was misnamed and found (not when we are joining)
-                    old_name = None
-                    if line.split()[1] == "Found" and not joinables:
-                        old_name = m.group(1)
-
-                    # Sometimes we don't know the total (filejoin)
-                    if verifytotal <= 1 or verifynum > verifytotal:
-                        nzo.set_action_line(T("Verifying"), "%02d" % verifynum)
-                    else:
-                        nzo.set_action_line(T("Verifying"), "%02d/%02d" % (verifynum, verifytotal))
-
-                elif old_name and old_name != m.group(1):
-                    # Hey we found another misnamed one!
-                    new_name = m.group(1)
-                    logging.debug('MultiPar will rename "%s" to "%s"', old_name, new_name)
-                    renames[new_name] = old_name
-                    # Need to remove the old file after repair (Multipar keeps it)
-                    used_for_repair.append(old_name)
-                    # Need to reset it to avoid collision
-                    old_name = None
-
-                if joinables:
-                    # Find out if a joinable file has been used for joining
-                    for jn in joinables:
-                        if get_filename(jn) == m.group(1):
-                            used_joinables.append(jn)
-                            break
-
-        elif line.startswith("Need"):
-            # We need more blocks, but are they available?
-            chunks = line.split()
-            needed_blocks = int(chunks[1])
-
-            # Check if we have enough blocks
-            added_blocks = nzo.get_extra_blocks(setname, needed_blocks)
-            if added_blocks:
-                msg = T("Fetching %s blocks...") % str(added_blocks)
-                nzo.set_action_line(T("Fetching"), msg)
-                readd = True
-            else:
-                # Failed
-                msg = T("Repair failed, not enough repair blocks (%s short)") % str(needed_blocks)
-                nzo.fail_msg = msg
-                nzo.set_unpack_info("Repair", msg, setname)
-                nzo.status = Status.FAILED
-
-            # MultiPar can say 'PAR File(s) Incomplete' also when it needs more blocks
-            # But the Need-more-blocks message is always last, so force failure
-            finished = False
-
-        # Result of verification
-        elif line.startswith("All Files Complete") or line.endswith("PAR File(s) Incomplete"):
-            # 'PAR File(s) Incomplete' is also reported for success when there are very similar filenames in the folder
-            # See: https://github.com/Yutaka-Sawada/MultiPar/issues/54
-            # Check if there was damage, by inspecting the number of missing blocks
-            if "Input File Slice lost" in lines[-2] and int(lines[-2].split()[-1]) == 0:
-                # Completed without damage!
-                msg = T("[%s] Verified in %s, all files correct") % (setname, format_time_string(time.time() - start))
-                nzo.set_unpack_info("Repair", msg)
-                logging.info("Verified in %s, all files correct", format_time_string(time.time() - start))
-                finished = True
-
-        elif line.startswith(("Ready to repair", "Ready to rejoin")):
-            # Ready to repair!
-            # Or we are re-joining a split file when there's no damage but takes time
-            msg = T("[%s] Verified in %s, repair is required") % (setname, format_time_string(time.time() - start))
-            nzo.set_unpack_info("Repair", msg)
-            logging.info("Verified in %s, repair is required", format_time_string(time.time() - start))
-            start = time.time()
-
-            # Set message for user in case of joining
-            if line.startswith("Ready to rejoin"):
-                # There is no status-update when it is joining
-                nzo.set_action_line(T("Joining"), "%2d" % len(used_joinables))
-
-        # ----------------- Repair stage
-        elif "Recovering slice" in line:
-            # Before this it will calculate matrix, here is where it starts
-            start = time.time()
-            in_repair = True
-            nzo.set_action_line(T("Repairing"), "%2d%%" % 0)
-
-        elif line.startswith("Verifying repair"):
-            in_repair = False
-            in_verify_repaired = True
-            # How many will be checked?
-            verifytotal = int(line.split()[-1])
-            verifynum = 0
-
-        elif in_repair:
-            try:
-                # Line with percentage of repair (nothing else)
-                perc = float(line[:-1])
-                nzo.set_action_line(T("Repairing"), "%2d%% %s" % (perc, add_time_left(perc, start)))
-                nzo.status = Status.REPAIRING
-            except:
-                # Checksum error
-                if "checksum" in line:
-                    # Failed due to checksum error of multipar
-                    msg = T("Repairing failed, %s") % line
-                    nzo.fail_msg = msg
-                    nzo.set_unpack_info("Repair", msg, setname)
-                    nzo.status = Status.FAILED
-                else:
-                    # Not sure, log error
-                    logging.info("Traceback: ", exc_info=True)
-
-        elif line.startswith("Repaired successfully"):
-            msg = T("[%s] Repaired in %s") % (setname, format_time_string(time.time() - start))
-            nzo.set_unpack_info("Repair", msg)
-            logging.info("Repaired in %s", format_time_string(time.time() - start))
-            finished = True
-
-        elif in_verify_repaired and line.startswith("Repaired :"):
-            # Track verification of repaired files (can sometimes take a while)
-            verifynum += 1
-            nzo.set_action_line(T("Verifying repair"), "%02d/%02d" % (verifynum, verifytotal))
-
-        elif line.startswith("Failed to repair") and not readd:
-            # Unknown repair problem
-            msg = T("Repairing failed, %s") % line
-            nzo.fail_msg = msg
-            nzo.set_unpack_info("Repair", msg, setname)
-            nzo.status = Status.FAILED
-            finished = True
-
-    p.wait()
-
-    # Also log what is shown to user in history
-    if nzo.fail_msg:
-        logging.info(nzo.fail_msg)
-
-    logging.debug("MultiPar output:\n%s", "\n".join(lines))
-
-    # Add renamed files to the collection
-    # MultiPar always automatically renames whatever it can in the 'Searching misnamed file:'-section
-    # Even if the repair did not complete fully it will rename those!
-    # But the ones in 'Finding available slices'-section will only be renamed after successful repair
-    if renames:
-        # If success, we also remove the possibly previously renamed ones
-        if finished:
-            reconstructed.extend(list(renames.values()))
-
-        # Adding to the collection
-        nzo.renamed_file(renames)
-
-        # Remove renamed original files
-        workdir = os.path.split(parfile)[0]
-        used_joinables.extend([os.path.join(workdir, name) for name in reconstructed])
-
-    return finished, readd, used_joinables, used_for_repair
-
-
 def create_env(nzo: Optional[NzbObject] = None, extra_env_fields: Dict[str, Any] = {}) -> Optional[Dict[str, Any]]:
     """Modify the environment for pp-scripts with extra information
     macOS: Return copy of environment without PYTHONPATH and PYTHONHOME
@@ -1790,7 +1440,6 @@ def create_env(nzo: Optional[NzbObject] = None, extra_env_fields: Dict[str, Any]
             "api_key": cfg.api_key(),
             "api_url": f"{sabnzbd.BROWSER_URL}/api",
             "par2_command": sabnzbd.newsunpack.PAR2_COMMAND,
-            "multipar_command": sabnzbd.newsunpack.MULTIPAR_COMMAND,
             "rar_command": sabnzbd.newsunpack.RAR_COMMAND,
             "7zip_command": sabnzbd.newsunpack.SEVENZIP_COMMAND,
             "version": sabnzbd.__version__,
