@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2008-2017 The SABnzbd-Team (sabnzbd.org)
+# Copyright 2008-2025 by The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -34,16 +34,14 @@ from typing import Optional, Dict, Any, Union, List, Tuple
 
 import sabnzbd
 from sabnzbd import nzbstuff
-from sabnzbd.encoding import utob, correct_unknown_encoding, correct_cherrypy_encoding
+from sabnzbd.encoding import utob, correct_cherrypy_encoding
 from sabnzbd.filesystem import (
     get_filename,
-    is_valid_script,
     get_ext,
     clip_path,
     remove_file,
-    remove_data,
 )
-from sabnzbd.misc import name_to_cat
+from sabnzbd.misc import name_to_cat, cat_pp_script_sanitizer
 from sabnzbd.constants import DEFAULT_PRIORITY, VALID_ARCHIVES, AddNzbFileResult
 from sabnzbd.utils import rarfile
 
@@ -62,23 +60,20 @@ def add_nzbfile(
     reuse: Optional[str] = None,
     password: Optional[str] = None,
     nzo_id: Optional[str] = None,
+    dup_check: bool = True,
 ):
     """Add file, either a single NZB-file or an archive.
     All other parameters are passed to the NZO-creation.
     """
-    if pp == "-1":
-        pp = None
-    if script and (script.lower() == "default" or not is_valid_script(script)):
-        script = None
-    if cat and cat.lower() == "default":
-        cat = None
+    # Base conversion of input
+    cat, pp, script = cat_pp_script_sanitizer(cat, pp, script)
 
     if isinstance(nzbfile, str):
         # File coming from queue repair or local file-path
         path = nzbfile
         filename = os.path.basename(path)
         keep_default = True
-        if not sabnzbd.WIN32:
+        if not sabnzbd.WINDOWS:
             # If windows client sends file to Unix server backslashes may
             # be included, so convert these
             path = path.replace("\\", "/")
@@ -123,6 +118,7 @@ def add_nzbfile(
             url=url,
             password=password,
             nzo_id=nzo_id,
+            dup_check=dup_check,
         )
     else:
         return process_single_nzb(
@@ -140,6 +136,7 @@ def add_nzbfile(
             url=url,
             password=password,
             nzo_id=nzo_id,
+            dup_check=dup_check,
         )
 
 
@@ -155,10 +152,10 @@ def process_nzb_archive_file(
     nzbname: Optional[str] = None,
     reuse: Optional[str] = None,
     nzo_info: Optional[Dict[str, Any]] = None,
-    dup_check: bool = True,
     url: Optional[str] = None,
     password: Optional[str] = None,
     nzo_id: Optional[str] = None,
+    dup_check: bool = True,
 ) -> Tuple[AddNzbFileResult, List[str]]:
     """Analyse archive and create job(s).
     Accepts archive files with ONLY nzb/nfo/folder files in it.
@@ -214,20 +211,20 @@ def process_nzb_archive_file(
                             cat=cat,
                             url=url,
                             priority=priority,
+                            password=password,
                             nzbname=nzbname,
                             nzo_info=nzo_info,
                             reuse=reuse,
                             nzo_id=nzo_id,
                             dup_check=dup_check,
                         )
-                        if not nzo.password:
-                            nzo.password = password
                     except (sabnzbd.nzbstuff.NzbEmpty, sabnzbd.nzbstuff.NzbRejected):
                         # Empty or fully rejected
                         pass
-                    except sabnzbd.nzbstuff.NzbRejectedToHistory as err:
-                        # Duplicate or unwanted extension that was failed to history
-                        nzo_ids.append(err.nzo_id)
+                    except sabnzbd.nzbstuff.NzbRejectToHistory as err:
+                        # Duplicate or unwanted extension directed to history
+                        sabnzbd.NzbQueue.fail_to_history(err.nzo)
+                        nzo_ids.append(err.nzo.nzo_id)
                     except:
                         # Something else is wrong, show error
                         logging.error(T("Error while adding %s, removing"), name, exc_info=True)
@@ -270,10 +267,10 @@ def process_single_nzb(
     nzbname: Optional[str] = None,
     reuse: Optional[str] = None,
     nzo_info: Optional[Dict[str, Any]] = None,
-    dup_check: bool = True,
     url: Optional[str] = None,
     password: Optional[str] = None,
     nzo_id: Optional[str] = None,
+    dup_check: bool = True,
 ) -> Tuple[AddNzbFileResult, List[str]]:
     """Analyze file and create a job from it
     Supports NZB, NZB.BZ2, NZB.GZ and GZ.NZB-in-disguise
@@ -321,23 +318,23 @@ def process_single_nzb(
             cat=cat,
             url=url,
             priority=priority,
+            password=password,
             nzbname=nzbname,
             nzo_info=nzo_info,
             reuse=reuse,
             nzo_id=nzo_id,
             dup_check=dup_check,
         )
-        if not nzo.password:
-            nzo.password = password
     except sabnzbd.nzbstuff.NzbEmpty:
         # Malformed or might not be an NZB file
         result = AddNzbFileResult.NO_FILES_FOUND
     except sabnzbd.nzbstuff.NzbRejected:
         # Rejected as duplicate or by pre-queue script
         result = AddNzbFileResult.ERROR
-    except sabnzbd.nzbstuff.NzbRejectedToHistory as err:
-        # Duplicate or unwanted extension that was failed to history
-        nzo_ids.append(err.nzo_id)
+    except sabnzbd.nzbstuff.NzbRejectToHistory as err:
+        # Duplicate or unwanted extension directed to history
+        sabnzbd.NzbQueue.fail_to_history(err.nzo)
+        nzo_ids.append(err.nzo.nzo_id)
     except:
         # Something else is wrong, show error
         logging.error(T("Error while adding %s, removing"), filename, exc_info=True)
@@ -422,8 +419,7 @@ def nzbfile_parser(full_nzb_path: str, nzo):
                 # Get segments
                 raw_article_db = {}
                 file_bytes = 0
-                bad_articles = False
-                if element.find("segments"):
+                if len(element.find("segments")):
                     for segment in element.find("segments").iter("segment"):
                         try:
                             article_id = segment.text
@@ -443,14 +439,12 @@ def nzbfile_parser(full_nzb_path: str, nzo):
                                         article_id,
                                     )
                                     nzo.increase_bad_articles_counter("duplicate_articles")
-                                    bad_articles = True
                                 else:
                                     logging.info("Skipping duplicate article (%s)", article_id)
                             elif segment_size <= 0 or segment_size >= 2**23:
                                 # Perform sanity check (not negative, 0 or larger than 8MB) on article size
                                 logging.info("Skipping article %s due to strange size (%s)", article_id, segment_size)
                                 nzo.increase_bad_articles_counter("bad_articles")
-                                bad_articles = True
                             else:
                                 raw_article_db[partnum] = (article_id, segment_size)
                                 file_bytes += segment_size
@@ -458,28 +452,25 @@ def nzbfile_parser(full_nzb_path: str, nzo):
                             # In case of missing attributes
                             pass
 
-                # Sort the articles by part number, compatible with Python 3.5
+                # Skip any empty files
+                if not raw_article_db:
+                    logging.info("No valid articles in %s, skipping", file_name)
+                    continue
+
+                # Get the articles, making sure to sort the articles by part number
                 raw_article_db_sorted = [raw_article_db[partnum] for partnum in sorted(raw_article_db)]
 
                 # Create NZF
-                nzf = sabnzbd.nzbstuff.NzbFile(file_date, file_name, raw_article_db_sorted, file_bytes, nzo)
-
-                # Check if we already have this exact NZF (see custom eq-checks)
-                if nzf in nzo.files:
-                    logging.info("File %s occurred twice in NZB, skipping", nzf.filename)
-                    remove_data(nzf.nzf_id, nzo.admin_path)
+                try:
+                    nzf = sabnzbd.nzbstuff.NzbFile(file_date, file_name, raw_article_db_sorted, file_bytes, nzo)
+                except sabnzbd.nzbstuff.SkippedNzbFile:
+                    # Did not meet requirements, so continue
+                    skipped_files += 1
                     continue
 
-                # Add valid NZF's
-                if file_name and nzf.valid and nzf.nzf_id:
-                    nzo.add_nzf(nzf)
-                    valid_files += 1
-                    avg_age_sum += file_timestamp
-                else:
-                    logging.info("Error importing %s, skipping", file_name)
-                    if nzf.nzf_id:
-                        remove_data(nzf.nzf_id, nzo.admin_path)
-                    skipped_files += 1
+                nzo.add_nzf(nzf)
+                valid_files += 1
+                avg_age_sum += file_timestamp
                 element.clear()
 
     # Final bookkeeping
