@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2024 by The SABnzbd-Team (sabnzbd.org)
+# Copyright 2007-2025 by The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -426,7 +426,7 @@ class NzbQueue:
                         # Force-remove all trace and update counters
                         nzo.bytes -= nzf.bytes
                         nzo.bytes_tried -= nzf.bytes - nzf.bytes_left
-                        if nzf.is_par2 or sabnzbd.par2file.is_parfile(nzf.filename):
+                        if nzf.is_par2 or sabnzbd.par2file.has_par2_in_filename(nzf.filename):
                             nzo.bytes_par2 -= nzf.bytes
                         del nzo.files_table[nzf_id]
                         nzo.finished_files.remove(nzf)
@@ -494,7 +494,7 @@ class NzbQueue:
             # to determine whether to change the priority
             nzo3 = self.__nzo_table[item_id_3]
             nzo3_priority = nzo3.priority
-            # if id1 is surrounded by items of a different priority then change it's pririty to match
+            # if id1 is surrounded by items of a different priority then change its priority to match
             if nzo2_priority != nzo1_priority and nzo3_priority != nzo1_priority or nzo2_priority > nzo1_priority:
                 nzo1.priority = nzo2_priority
         except:
@@ -669,16 +669,6 @@ class NzbQueue:
         except:
             return -1
 
-    @staticmethod
-    def reset_try_lists(article: Article, remove_fetcher_from_trylist: bool = True):
-        """Let article get new fetcher and reset trylists"""
-        if remove_fetcher_from_trylist:
-            article.remove_from_try_list(article.fetcher)
-        article.fetcher = None
-        article.tries = 0
-        article.nzf.reset_try_list()
-        article.nzf.nzo.reset_try_list()
-
     def has_forced_jobs(self) -> bool:
         """Check if the queue contains any Forced
         Priority jobs to download while paused
@@ -738,11 +728,10 @@ class NzbQueue:
             or (articles_left and (articles_left % sabnzbd.ArticleCache.assembler_write_trigger) == 0)
         ):
             if not nzo.precheck:
-                # Only start decoding if we have a filename and type
                 # The type is only set if sabctools could decode the article
-                if nzf.filename and nzf.type:
+                if nzf.type:
                     sabnzbd.Assembler.process(nzo, nzf, file_done)
-                elif nzf.filename.lower().endswith(".par2"):
+                elif sabnzbd.par2file.has_par2_in_filename(nzf.filename):
                     # Broken par2 file, try to get another one
                     nzo.promote_par2(nzf)
 
@@ -873,11 +862,10 @@ class NzbQueue:
     def stop_idle_jobs(self):
         """Detect jobs that have zero files left and send them to post processing"""
         # Only check servers that are active
-        active_servers = [server for server in sabnzbd.Downloader.servers[:] if server.active]
-        nr_servers = len(active_servers)
+        active_servers = set(server for server in sabnzbd.Downloader.servers[:] if server.active)
         empty = []
 
-        if nr_servers <= 0:
+        if len(active_servers) <= 0:
             logging.debug("Skipping stop_idle_jobs because no servers are active")
             return
 
@@ -886,25 +874,26 @@ class NzbQueue:
                 logging.info("Found idle job %s", nzo.final_name)
                 empty.append(nzo)
 
-            # Stall prevention by checking if all servers are in the trylist
+            # Stall prevention by checking if all servers are in the try list
             # This is a CPU-cheaper alternative to prevent stalling
-            if len(nzo.try_list) >= nr_servers:
+            if nzo.all_servers_in_try_list(active_servers):
                 # Maybe the NZF's need a reset too?
                 for nzf in nzo.files:
                     if nzo.removed_from_queue:
                         break
 
-                    if len(nzf.try_list) >= nr_servers:
+                    if nzf.all_servers_in_try_list(active_servers):
                         # Check for articles where all active servers have already been tried
                         for article in nzf.articles[:]:
                             if article.all_servers_in_try_list(active_servers):
-                                sabnzbd.NzbQueue.register_article(article, success=False)
+                                logging.debug("Removing article %s with bad trylist in file %s", article, nzf.filename)
                                 nzo.increase_bad_articles_counter("missing_articles")
+                                sabnzbd.NzbQueue.register_article(article, success=False)
 
                         logging.info("Resetting bad trylist for file %s in job %s", nzf.filename, nzo.final_name)
                         nzf.reset_try_list()
 
-                # Reset main trylist, minimal performance impact
+                # Reset main try list, minimal performance impact
                 logging.info("Resetting bad trylist for job %s", nzo.final_name)
                 nzo.reset_try_list()
 
