@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2024 by The SABnzbd-Team (sabnzbd.org)
+# Copyright 2007-2025 by The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -42,7 +42,6 @@ from threading import Thread
 from sabnzbd.misc import (
     on_cleanup_list,
     is_sample,
-    helpful_warning,
     history_updated,
     change_queue_complete_action,
     run_script,
@@ -71,8 +70,6 @@ from sabnzbd.filesystem import (
     get_unique_filename,
     get_ext,
     get_filename,
-    directory_is_writable,
-    check_filesystem_capabilities,
 )
 from sabnzbd.nzbstuff import NzbObject
 from sabnzbd.sorting import Sorter
@@ -262,34 +259,6 @@ class PostProcessor(Thread):
 
     def run(self):
         """Postprocessor loop"""
-        # First we do a dircheck
-        complete_dir = sabnzbd.cfg.complete_dir.get_path()
-        if sabnzbd.utils.checkdir.isFAT(complete_dir):
-            helpful_warning(
-                T("Completed Download Folder %s is on FAT file system, limiting maximum file size to 4GB")
-                % complete_dir
-            )
-        else:
-            logging.debug("Completed Download Folder %s is not on FAT", complete_dir)
-
-        if directory_is_writable(sabnzbd.cfg.download_dir.get_path()):
-            check_filesystem_capabilities(sabnzbd.cfg.download_dir.get_path())
-        if directory_is_writable(sabnzbd.cfg.complete_dir.get_path()):
-            check_filesystem_capabilities(sabnzbd.cfg.complete_dir.get_path())
-
-        # Do an extra purge of the history on startup to ensure timely removal on systems that
-        # aren't on 24/7 and typically don't benefit from the daily scheduled call at midnight
-        database.scheduled_history_purge()
-
-        # Check for Apprise notification script
-        # We don't have a much better place to do this, since there's no notifier-thread
-        # TODO: Remove in 4.4
-        if sabnzbd.cfg.nscript_script() == "sabnzbd-notify.py":
-            helpful_warning(
-                "NZB-Notify has been integrated into SABnzbd. You can now use the "
-                "Apprise section to configure the same notifications."
-            )
-
         # Start looping
         check_eoq = False
         while not self.__stop:
@@ -495,12 +464,12 @@ def process_job(nzo: NzbObject) -> bool:
             if all_ok:
                 # Move any (left-over) files to destination
                 nzo.status = Status.MOVING
-                nzo.set_action_line(T("Moving"), "...")
                 for root, _, files in os.walk(nzo.download_path):
                     if not root.endswith(JOB_ADMIN):
                         for file in files:
                             path = os.path.join(root, file)
                             new_path = path.replace(nzo.download_path, tmp_workdir_complete)
+                            nzo.set_action_line(T("Moving"), file)
                             ok, new_path = move_to_path(path, new_path)
                             if new_path:
                                 newfiles.append(new_path)
@@ -582,7 +551,9 @@ def process_job(nzo: NzbObject) -> bool:
                 if cfg.deobfuscate_final_filenames():
                     # Deobfuscate the filenames
                     logging.info("Running deobfuscate")
-                    deobfuscate.deobfuscate(nzo, newfiles, nzo.final_name)
+                    newfiles = deobfuscate.deobfuscate(nzo, newfiles, nzo.final_name)
+                    # Deobfuscate the subtitles
+                    deobfuscate.deobfuscate_subtitles(nzo, newfiles)
 
                 # Run the user script
                 if script_path := make_script_path(script):
