@@ -1,6 +1,6 @@
 #!/usr/bin/python3 -OO
 # -*- coding: UTF-8 -*-
-# Copyright 2007-2023 The SABnzbd-Team (sabnzbd.org)
+# Copyright 2007-2025 by The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -28,6 +28,7 @@ SKIN_TEXT = {
     "stage-unpack": TT("Unpack"),  #: PP phase "unpack"
     "stage-deobfuscate": TT("Deobfuscate"),  #: PP phase "deobfuscate"
     "stage-script": TT("Script"),  #: PP phase "script"
+    "stage-rss": TT("RSS"),  #: PP RSS feed  of the NZB
     "stage-source": TT("Source"),  #: PP Source of the NZB (path or URL)
     "stage-servers": TT("Servers"),  #: PP Distribution over servers
     "post-Completed": TT("Completed"),  #: PP status
@@ -103,9 +104,10 @@ SKIN_TEXT = {
     "parameters": TT("Parameters"),  #: Config: startup parameters of SABnzbd
     "pythonVersion": TT("Python Version"),
     "notAvailable": TT("Not available"),
+    "empty": TT("Empty"),
     "homePage": TT("Home page"),  #: Home page of the SABnzbd project
     "source": TT("Source"),  #: Where to find the SABnzbd sourcecode
-    "or": TT("or"),  #: Used in "IRC or IRC-Webaccess"
+    "or": TT("or"),
     "host": TT("Host"),
     "cancel": TT("Cancel"),
     "login": TT("Log in"),
@@ -125,7 +127,7 @@ SKIN_TEXT = {
     "menu-help": TT("Help"),  #: Main menu item
     "menu-wiki": TT("Wiki"),  #: Main menu item
     "menu-forums": TT("Forum"),  #: Main menu item
-    "menu-irc": TT("IRC"),  #: Main menu item
+    "menu-live-chat": TT("Live Chat"),  #: Main menu item
     "menu-issues": TT("Issues"),  #: Main menu item
     "menu-donate": TT("Support the project, Donate!"),  #: Main menu item
     "cmenu-general": TT("General"),  #: Main menu item
@@ -169,24 +171,27 @@ SKIN_TEXT = {
     "mode": TT("Processing"),  #: Queue page table column header
     "name": TT("Name"),  #: Queue page table column header
     "button-retry": TT("Retry"),  #: Queue page button
-    "eoq-actions": TT("Actions"),  #: Queue end-of-queue selection box
     "eoq-scripts": TT("Scripts"),  #: Queue page table, script selection menu
     "purgeQueue": TT("Purge Queue"),  #: Queue page button
     "purgeQueueConf": TT("Delete all items from the queue?"),  #: Confirmation popup
+    "confirm-delete": TT("Are you sure you want to remove these jobs?"),  #: Delete confirmation popup
     "purgeNZBs": TT("Purge NZBs"),  #: Queue page button
     "purgeNZBs-Files": TT("Purge NZBs & Delete Files"),  #: Queue page button
     "removeNZB": TT("Remove NZB"),  #: Queue page button
     "removeNZB-Files": TT("Remove NZB & Delete Files"),  #: Queue page button
+    "permanently-delete": TT("Permanently delete (skip archive)"),  #: Checkbox if job should be added to Archive
     "missingArt": TT("Missing articles"),  #: Caption for missing articles in Queue
     "quota-left": TT("Quota left"),  #: Remaining quota (displayed in Queue)
     "manual": TT("manual"),  #: Manual reset of quota
     "link-resetQuota": TT("Reset Quota now"),
     # History page
+    "archive": TT("Archive"),
     "purgeHist": TT("Purge History"),  #: History page button
     "hideDetails": TT("Hide details"),  #: Button/link hiding History job details
     "showDetails": TT("Show details"),  #: Button/link showing History job details
     "showFailedHis": TT("Show Failed"),  #: Button or link showing only failed History jobs. DON'T MAKE THIS VERY LONG!
     "showAllHis": TT("Show All"),  #: Button or link showing all History jobs
+    "showArchive": TT("Show Archive"),  #: Button showing all archived jobs
     "size": TT("Size"),  #: History table header
     "status": TT("Status"),  #: History table header
     "purgeFailed": TT("Purge Failed NZBs"),  #: Button to delete all failed jobs in History
@@ -237,6 +242,7 @@ SKIN_TEXT = {
     # Configuration
     "confgFile": TT("Config File"),
     "cache": TT("Used cache"),  #: Main config page, how much cache is in use
+    "platform": TT("Platform"),  #: What platform we are on (e.g. Windows/macOS/Ubuntu/UnRaid/etc)
     "explain-Restart": TT(
         "This will restart SABnzbd.<br />Use it when you think the program has a stability problem.<br />Downloading will be paused before the restart and resume afterwards."
     ),
@@ -252,9 +258,6 @@ SKIN_TEXT = {
     "confirmWithoutSavingPrompt": TT("Changes have not been saved, and will be lost."),
     "explain-sessionExpire": TT("When your IP address changes or SABnzbd is restarted the session will expire."),
     "opt-enable_7zip": TT("Enable 7zip"),
-    "explain-nosslcontext": TT(
-        "Secure (SSL) connections from SABnzbd to newsservers and HTTPS websites will be encrypted, however, validating a server's identity using its certificates is not possible. OpenSSL 1.0.2 or above and up-to-date local CA certificates are required."
-    ),
     "explain-getpar2turbo": TT("Speed up repairs by installing par2cmdline-turbo, it is available for many platforms."),
     "version": TT("Version"),
     "uptime": TT("Uptime"),
@@ -268,8 +271,8 @@ SKIN_TEXT = {
     "explain-host": TT("Host SABnzbd should listen on."),
     "opt-port": TT("SABnzbd Port"),
     "explain-port": TT("Port SABnzbd should listen on."),
-    "opt-web_dir": TT("Web Interface"),
-    "explain-web_dir": TT("Choose a skin."),
+    "opt-web_dir": TT("Web Interface Theme"),
+    "explain-web_dir": TT("Choose a theme."),
     "opt-web_username": TT("SABnzbd Username"),
     "explain-web_username": TT("Optional authentication username."),
     "opt-web_password": TT("SABnzbd Password"),
@@ -313,13 +316,13 @@ SKIN_TEXT = {
         "List of file extensions that should be deleted after download.<br />For example: <b>nfo</b> or <b>nfo, sfv</b>"
     ),
     "opt-history_retention": TT("History Retention"),
-    "explain-history_retention": TT(
-        "Automatically delete completed jobs from History. Beware that Duplicate Detection and some external tools rely on History information."
-    ),
     "history_retention-all": TT("Keep all jobs"),
-    "history_retention-number": TT("Keep maximum number of completed jobs"),
-    "history_retention-days": TT("Keep completed jobs maximum number of days"),
-    "history_retention-none": TT("Do not keep any completed jobs"),
+    "history_retention-number-archive": TT("Move jobs to the archive if the history exceeds specified number of jobs"),
+    "history_retention-number-delete": TT("Delete jobs if the history and archive exceeds specified number of jobs"),
+    "history_retention-days-archive": TT("Move jobs to the archive after specified number of days"),
+    "history_retention-days-delete": TT("Delete jobs from the history and archive after specified number of days"),
+    "history_retention-archive": TT("Move all completed jobs to archive"),
+    "history_retention-none": TT("Delete all completed jobs"),
     "history_retention-limit": TT("Jobs"),
     "button-saveChanges": TT("Save Changes"),
     "button-restoreDefaults": TT("Restore Defaults"),
@@ -415,24 +418,20 @@ SKIN_TEXT = {
     ),
     "opt-pause_on_pwrar": TT("Action when encrypted RAR is downloaded"),
     "explain-pause_on_pwrar": TT('In case of "Pause", you\'ll need to set a password and resume the job.'),
-    "opt-no_dupes": TT("Detect Duplicate Downloads"),
-    "explain-no_dupes": TT(
-        "Detect identical NZB files (based on items in your History or files in .nzb Backup Folder)"
-    ),
-    "opt-no_series_dupes": TT("Detect duplicate episodes in series"),
-    "explain-no_series_dupes": TT(
-        'Detect identical episodes in series (based on "name/season/episode" of items in your History)'
-    ),
-    "opt-series_propercheck": TT("Allow proper releases"),
-    "explain-series_propercheck": TT(
-        "Bypass series duplicate detection if PROPER, REAL or REPACK is detected in the download name"
+    "opt-no_dupes": TT("Identical download detection"),
+    "explain-no_dupes": TT("Detect identical downloads based on name or NZB contents."),
+    "opt-no_smart_dupes": TT("Smart duplicate detection"),
+    "explain-no_smart_dupes": TT("Detect duplicates based on analysis of the filename."),
+    "opt-dupes_propercheck": TT("Allow proper releases"),
+    "explain-dupes_propercheck": TT(
+        "Bypass smart duplicate detection if PROPER, REAL or REPACK is detected in the download name."
     ),
     "nodupes-off": TT("Off"),  #: Three way switch for duplicates
     "nodupes-ignore": TT("Discard"),  #: Four way switch for duplicates
     "nodupes-pause": TT("Pause"),  #: Four way switch for duplicates
-    "nodupes-fail": TT("Fail job (move to History)"),  #: Four way switch for duplicates
     "nodupes-tag": TT("Tag job"),  #: Four way switch for duplicates
-    "abort": TT("Abort"),  #: Three way switch for encrypted posts
+    "fail-to-history": TT("Fail job (move to History)"),  #: Four way switch for duplicates
+    "abort": TT("Abort post-processing"),
     "opt-action_on_unwanted_extensions": TT("Action when unwanted extension detected"),
     "explain-action_on_unwanted_extensions": TT("Action when an unwanted extension is detected"),
     "opt-unwanted_extensions": TT("Unwanted extensions"),
@@ -453,14 +452,12 @@ SKIN_TEXT = {
     ),
     "opt-pre_script": TT("Pre-queue user script"),
     "explain-pre_script": TT("Used before an NZB enters the queue."),
+    "opt-end_queue_script": TT("On queue finish script"),
+    "explain-end_queue_script": TT("Executed after the queue finishes downloading."),
     "opt-par_option": TT("Extra PAR2 Parameters"),
-    "explain-par_option": TT("Read the Wiki Help on this!"),
     "opt-nice": TT("Nice Parameters"),
-    "explain-nice": TT("Read the Wiki Help on this!"),
     "opt-ionice": TT("IONice Parameters"),
-    "explain-ionice": TT("Read the Wiki Help on this!"),
     "opt-win_process_prio": TT("External process priority"),
-    "explain-win_process_prio": TT("Read the Wiki Help on this!"),
     "win_process_prio-high": TT("High"),
     "win_process_prio-normal": TT("Normal"),
     "win_process_prio-low": TT("Low"),
@@ -479,7 +476,6 @@ SKIN_TEXT = {
         "Posts will be paused untill they are at least this age. Setting job priority to Force will skip the delay."
     ),
     "opt-check_new_rel": TT("Check for New Release"),
-    "explain-check_new_rel": TT("Weekly check for new SABnzbd release."),
     "also-test": TT("Also test releases"),  #: Pick list for weekly test for new releases
     "opt-replace_spaces": TT("Replace Spaces in Foldername"),
     "explain-replace_spaces": TT("Replace spaces with underscores in folder names."),
@@ -555,10 +551,15 @@ SKIN_TEXT = {
     "explain-ssl": TT("Secure connection to server"),  #: Server SSL tickbox
     "opt-ssl_verify": TT("Certificate verification"),
     "explain-ssl_verify": TT(
-        "Minimal: when SSL is enabled, verify the identity of the server using its certificates. Strict: verify and enforce matching hostname."
+        "When SSL is enabled: "
+        "- Strict: enforce full certificate verification. This is the most secure setting. "
+        "- Medium: verify that the certificate is valid and matches the server address, but allow certificates locally injected (for example by firewall or virus scanner)."
+        "- Minimal: verify that the certificate is valid. This is not secure, any valid certificate could be used. "
+        "- Disabled: no certification verification. This is not secure at all, anyone could intercept your connection. "
     ),
     "ssl_verify-disabled": TT("Disabled"),
-    "ssl_verify-normal": TT("Minimal"),
+    "ssl_verify-minimal": TT("Minimal"),
+    "ssl_verify-medium": TT("Medium"),
     "ssl_verify-strict": TT("Strict"),
     "srv-priority": TT("Priority"),  #: Server priority
     "explain-svrprio": TT("0 is highest priority, 100 is the lowest priority"),  #: Explain server priority
@@ -577,8 +578,6 @@ SKIN_TEXT = {
     "button-clrServer": TT("Clear Counters"),  #: Button: Clear server's byte counters
     "srv-testing": TT("Testing server details..."),
     "srv-bandwidth": TT("Bandwidth"),
-    "srv-send_group": TT("Send Group"),
-    "srv-explain-send_group": TT("Send group command before requesting articles."),
     "srv-notes": TT("Personal notes"),
     "srv-article-availability": TT("Article availability"),
     "srv-articles-tried": TT(
@@ -683,13 +682,21 @@ SKIN_TEXT = {
     "explain-pushbullet_apikey": TT("Your personal Pushbullet API key (required)"),  #: Pushbullet settings
     "opt-pushbullet_device": TT("Device"),  #: Pushbullet settings
     "explain-pushbullet_device": TT("Device to which message should be sent"),  #: Pushbullet settings
+    "opt-apprise_enable": TT("Enable Apprise notifications"),  #: Apprise settings
+    "explain-apprise_enable": TT(
+        "Send notifications using Apprise to almost any notification service"
+    ),  #: Apprise settings
+    "opt-apprise_urls": TT("Default Apprise URLs"),  #: Apprise settings
+    "explain-apprise_urls": TT("Use a comma and/or space to identify more than one URL."),  #: Apprise settings
+    "explain-apprise_extra_urls": TT(
+        "Override the default URLs for specific notification types below, if desired."
+    ),  #: Apprise settings
     "section-NScript": TT("Notification Script"),  #: Header for Notification Script notification section
     "opt-nscript_enable": TT("Enable notification script"),  #: Notification Script settings
     "opt-nscript_script": TT("Script"),  #: Notification Script settings
     "opt-nscript_parameters": TT("Parameters"),  #: Notification Script settings
     "explain-nscript_enable": TT("Executes a custom script"),  #: Notification Scriptsettings
     "explain-nscript_script": TT("Which script should we execute for notification?"),  #: Notification Scriptsettings
-    "explain-nscript_parameters": TT("Read the Wiki Help on this!"),  #: Notification Script settings
     # Config->Cat
     "explain-catTags": TT(
         'Indexers can supply a category inside the NZB which SABnzbd will try to match to the categories defined below. Additionally, you can add terms to "Indexer Categories / Groups" to match more categories. Use commas to separate terms. Wildcards in the terms are supported. <br>More information can be found on the Wiki.'
@@ -842,6 +849,9 @@ SKIN_TEXT = {
     "Glitter-top": TT("Top"),
     "Glitter-bottom": TT("Bottom"),
     "Glitter-retryJob": TT("Retry"),
+    "Glitter-retryNoChecks": TT(
+        "When you Retry a job, 'Duplicate Detection' and 'Abort jobs that cannot be completed' are disabled."
+    ),
     "Glitter-more": TT("More"),
     "Glitter-scriptLog": TT("View Script Log"),
     "Glitter-clearHistory": TT("Purge History"),
